#
# spec file for package scap-workbench
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           scap-workbench
Version:        1.2.1+git20221219.10c1929
Release:        2.3
Summary:        A SCAP scanner and SCAP content editor
License:        GPL-3.0-only
Group:          Productivity/Security
URL:            https://github.com/OpenSCAP/%{name}
Source:         %{version}/%{name}-%{version}.tar.gz
Patch0:         0001-pkexec-avoid-potential-local-root-exploit-by-using-P.patch
BuildRequires:  asciidoc
BuildRequires:  cmake >= 2.6
BuildRequires:  openscap-devel >= 1.3.7
# buildtime and runtime requires for remote scan detection
BuildRequires:  openssh
Recommends:     openssh
# SLE 11 SP3: libopenscap needs libxslt without requiring it
# libxslt needs pcre
%if 0%{?suse_version} < 1140
BuildRequires:  libxslt-devel
BuildRequires:  pcre-devel
%endif
BuildRequires:  pkg-config
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5XmlPatterns)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

# scap-security-guide provides 'content'
Recommends:     scap-security-guide

# openscap-utils provides 'oscap' to run profiles
Recommends:     openscap-utils

%description
The main goal of this application is to lower the initial barrier of
using SCAP. Therefore, the scope of very narrow - scap-workbench only
scans a single machine and only with XCCDF/SDS (no direct OVAL
evaluation). The assumption is that this is enough for users who want
to scan a few machines and users with huge amount of machines to scan
will just use scap-workbench to test or hand-tune their content before
deploying it with more advanced (and harder to use) tools like
spacewalk.

%package doc
Summary:        Documentation for scap-workbench
Group:          Documentation/HTML

%description doc
This package provides HTML documentation for scap-workbench.

%prep
%autosetup -p1

%build
%if 0%{?cmake}
%cmake -DCMAKE_INSTALL_DOCDIR=%{_docdir}/%{name} -DCMAKE_INSTALL_LIBEXECDIR=%{_libdir}/%{name}
%else
rm -rf build
mkdir build
pushd build
 cmake -DCMAKE_INSTALL_PREFIX=/usr\
   -DCMAKE_VERBOSE_MAKEFILE=TRUE\
   -DCMAKE_SKIP_RPATH=1\
   -DPACKAGE_ARCHITECTURE=`uname -m`\
   -DCMAKE_INSTALL_DOCDIR=%{_docdir}/%{name}\
   -DCMAKE_INSTALL_LIBEXECDIR=%{_libdir}/%{name}\
   ..
popd
%endif
pushd build
make %{?_smp_mflags}
popd

%install
pushd build
%make_install
rm -rf %{buildroot}%{_docdir}/%{name}/COPYING
popd

%if 0%{?suse_version}
%suse_update_desktop_file -i -u org.open_scap.scap_workbench Utility DesktopUtility
%endif

%files
%defattr(-,root,root,0755)
%doc README.md
%license COPYING
%{_bindir}/%{name}
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/*.appdata.xml
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*.png
%dir %{_datadir}/%{name}/translations
%{_datadir}/%{name}/translations/README
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/%{name}*
%dir %{_datadir}/polkit-1
%dir %{_datadir}/polkit-1/actions
%{_datadir}/polkit-1/actions/%{name}*
%{_mandir}/man8/%{name}*
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/*sh
%exclude %{_docdir}/%{name}/*.html
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

%files doc
%defattr(-,root,root,0755)
%doc %{_docdir}/%{name}/*.html

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Tue Mar 28 2023 kkaempf@suse.com
- Update to version 1.2.1+git20221219.10c1929:
  * Use version 1 of get package for Ubuntu package installation.
  * Replace words with "control".
  * Use fedora latest to build scap-workbench.
  * Switch branch target to main.
  * Remove obsoleted sources of SCAP content from the manual
  * Update manual with how to obtain content from upstream source
  * Fix appdata, desktop and icons for Linux (Freedesktop)
* Thu Jan 13 2022 Marcus Meissner <meissner@suse.com>
- require "ssh" at buildtime to enable remote mode. (bsc#1194604)
* Fri Jun  4 2021 Klaus Kämpf <kkaempf@suse.com>
- Update to 1.2.1+git20210604.1fc6def to fix Factory build
- drop 0001-Port-Qt5-deprecated-methods.patch (upstream)
* Wed Mar 25 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.2.1. No changelog.
- Rebase 0001-pkexec-avoid-potential-local-root-exploit-by-using-P.patch
- Drop 0002-Qt5-deprecations.patch. Merged upstream
- Add 0001-Port-Qt5-deprecated-methods.patch
* Fri Oct 11 2019 Klaus Kämpf <kkaempf@suse.com>
- fix Qt5 deprecation warnings
  0002-Qt5-deprecations.patch
* Sat Apr 13 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.2.0. Changes since 1.1.5:
  * ported from Qt4 to Qt5
  * UX improvements
  * Generate bash and Ansible remediation roles from profiles
  * Generate bash and Ansible remediation roles from results after
    scanning
  * Fixed a short integer overflow when using ssh port numbers
    higher than 32k
* Thu Jul 26 2018 matthias.gerstner@suse.com
- 0001-pkexec-avoid-potential-local-root-exploit-by-using-P.patch:
  harden and sanitize the pkexec wrapper (bsc#1084706).
* Sat Dec 30 2017 jengelh@inai.de
- Fix RPM groups. Optimize unnecessary subshell calls.
* Wed Sep 20 2017 zaitor@opensuse.org
- Update to version 1.1.5:
  + Highlights: Tri-state checkboxes in Tailoring Window.
  + Bugfixes:
  - Fixed remote host and port being cleared when scan starts
  - Fixed formating of Profile html description in Tailoring Window
  - Fixed oscap message "Downloading ... ok" appearing as an error
  + Other improvements:
  - Fixed tab order of widgets in main window.
  - Load Content as the default button of the SSG integration
    dialog.
  - New validation of the customization file name.
- Drop obsolete and unused conditional libwebkitgtk-devel and
  libwebkit-devel BuildRequires, this dependency was dropped in
  version 0.0.8 upstream.
* Mon Jan 16 2017 meissner@suse.com
- Update to 1.1.4
  - Highlights
    Fix --fetch-remote-resources warning with older openscap
  - Bugfixes
    Check capabilities of oscap with propper arguments
  - Other improvements
    Show number of selected rules in profile listing
    Enable High DPI mode in MacOSX builds
    Remove fixed sizes of checkboxes and Port label
    Improve UX of recent remote machine history list
  - See https://github.com/OpenSCAP/scap-workbench/issues?q=milestone%%3A1.1.4 for more details
- Update to 1.1.3
  - Highlights
    UX improvements
    Improved error message when scanning a remote machine in which openscap-scanner is not installed
  - Bugfixes
    Fixed search on disabled item
    Fixed multi benchmark tailoring use case
    Fixed a bug that caused tailored profiles to have titles duplicated
    Fixed path of tailoring file in dry run output
    Fixed fetch remote resources warning
  - Other improvements
    Added a helper script that builds SCAP Workbench for OSX
    Now Workbench doesn't allow edit of values with prohibitedChanges attribute
    Added --version and --help command line options
    Improved workflow of dry run execution
  - See https://github.com/OpenSCAP/scap-workbench/issues?q=milestone%%3A1.1.3 for more details
- Update to 1.1.2:
  - New feature: "dry-run" - see which oscap arguments you have to use to do the same evaluation as SCAP Workbench as it is currently set.
  - Minor bugfixes:
    fixed checklist combobox when a datastream with multiple benchmarks is opened
    fixed minor licensing issues
  - See https://github.com/OpenSCAP/scap-workbench/issues?q=milestone%%3A1.1.2 for more
* Mon Oct 12 2015 kkaempf@suse.com
- Update to 1.1.1
  Bugfix release
* Mon Oct 12 2015 kkaempf@suse.com
- take ownership of /usr/share/polkit-1*
* Thu Mar 26 2015 meissner@suse.com
- updated to 1.1.0
  Shiny new major release of SCAP Workbench. A lot of UX improvements
  and many new exciting features including a much better SCAP Security
  Guide integration. Downstreams are now encouraged to depend on
  scap-security-guide.
* Thu Feb  5 2015 kkaempf@suse.com
- Require libqt4-devel >= 4.8
* Fri Jan  9 2015 meissner@suse.com
- version 1.0.3
  This is a maintenance release with many bugfixes, usability improvements
  and documentation fixes. All users are recommended to update.
  See https://fedorahosted.org/scap-workbench/query?group=status&milestone=1.0.3
  for full list of changes.
- scap-workbench-0.8.6.patch: upstream
* Sat Feb  8 2014 kkaempf@suse.com
- fix path to bash, add scap-workbench-0.8.6.patch
* Sat Feb  8 2014 kkaempf@suse.com
- Initial version 0.8.6
